@@ -3,9 +3,9 @@
 ;; Copyright (C) 2021 Free Software Foundation, Inc.
 
 ;; Author: Tyler Grinn <tylergrinn@gmail.com>
-;; Version: 2.1.2
+;; Version: 2.1.3
 ;; File: boxy-headings.el
-;; Package-Requires: ((emacs "26.1") (boxy "1.0") (org "9.3"))
+;; Package-Requires: ((emacs "26.1") (boxy "1.0") (org "9.4"))
 ;; Keywords: tools
 ;; URL: https://gitlab.com/tygrdev/boxy-headings
 
@@ -277,6 +277,7 @@ diagram."
                                        columns
                                        "\n")
                             :markers (list (set-marker (point-marker) pos))
+                            :post-jump-hook 'org-reveal
                             :in-front (string= rel "in front of")
                             :on-top (string= rel "on top of")
                             :y-order (cond
@@ -304,11 +305,9 @@ diagram."
   "Create a `boxy-box' from the current buffer's headings."
   (org-columns-get-format)
   (let* ((headings (cddr (org-element-parse-buffer 'headline)))
-         (filename (buffer-name))
-         (title (or (concat (file-name-base filename) "." (file-name-extension filename))
-                    "Document"))
+         (title (cadr (car (org-collect-keywords '("title")))))
          (world (boxy-box))
-         (document (boxy-box :name title
+         (document (boxy-box :name (or title (buffer-name) "Document")
                              :tooltip ""
                              :markers (list (point-min-marker)))))
     (boxy-add-next document world)
